@@ -25,7 +25,7 @@ import ConfigParser
 
 from TrayIcon import TrayIcon
 
-from more import get_sid, get_view_params, _print
+from more import get_sid, get_view_params, _print, get_icon
 from MainClass import ApiClient
 from calculate.consolegui.datavars import DataVarsGui
 from pid_information import client_pid_info
@@ -55,10 +55,8 @@ class SelectedMethodWgt(qt.QWidget):
         layout.setSpacing(0)
         layout.addWidget(self.MethodWidget)
 
-        qt.QIcon.setThemeName('Calculate')
-        icon = qt.QIcon.fromTheme('cl-console-gui-%s'%self.method.replace("_","-"))
-        if icon.isNull():
-            icon = qt.QIcon.fromTheme('calculate-%s'%self.method.replace("_","-"))
+        icon = get_icon('cl-console-gui-%s'%self.method.replace("_","-"),
+                        'calculate-%s'%self.method.replace("_","-"))
 
         self.setWindowIcon(icon)
         qt.QApplication.setWindowIcon(icon)
@@ -208,12 +206,12 @@ class SelectedMethodWgt(qt.QWidget):
         # translate
         msgBox.button(msgBox.Yes).setText(_('Yes'))
         msgBox.button(msgBox.No).setText(_('No'))
-        if qt.QIcon.hasThemeIcon('dialog-close'):
-            msgBox.button(msgBox.No).setIcon \
-                                    (qt.QIcon.fromTheme('dialog-close'))
+        icon = get_icon('dialog-close')
+        if not icon.isNull():
+            msgBox.button(msgBox.No).setIcon(icon)
 
         msgBox.setDefaultButton(qt.QMessageBox.No)
-        msgBox.setWindowIcon(qt.QIcon.fromTheme("application-exit"))
+        msgBox.setWindowIcon(get_icon("application-exit"))
         reply = msgBox.exec_()
         return reply
 
@@ -293,12 +291,9 @@ class ToolTabWidget(qt.QTabWidget):
         self.tabbar = MyTabBar(self)
         self.setTabBar(self.tabbar)
 
-        qt.QIcon.setThemeName('Calculate')
-        self.gui_icon = qt.QIcon.fromTheme("video-display")
+        self.gui_icon = get_icon("video-display")
 
-        self.other_icon = qt.QIcon.fromTheme("list-add")
-        if self.other_icon.isNull():
-            self.other_icon = qt.QIcon.fromTheme("preferences-desctop")
+        self.other_icon = get_icon("list-add", "preferences-desktop")
 
         self.addTab(self.FirstWidget, self.gui_icon , self.new_con_txt)
         self.addTab(self.PlusWidget, self.other_icon, '')
@@ -380,14 +375,14 @@ class ToolTabWidget(qt.QTabWidget):
     def set_offline_icon(self):
         if self.current_icon != "offline":
             self.current_icon = "offline"
-            self.setWindowIcon(qt.QIcon \
-                        ('/usr/share/pixmaps/calculate-console-offline.svg'))
+            self.setWindowIcon(get_icon(
+                '/usr/share/pixmaps/calculate-console-offline.svg'))
 
     def set_online_icon(self):
         if self.current_icon != "online":
             self.current_icon = "online"
-            self.setWindowIcon(qt.QIcon \
-                        ('/usr/share/pixmaps/calculate-console-online.svg'))
+            self.setWindowIcon(get_icon(
+                '/usr/share/pixmaps/calculate-console-online.svg'))
 
     def connect_count_changed(self, host, port, count):
         if count:
