@@ -15,7 +15,7 @@
 #  limitations under the License.
 
 from calculate.consolegui import qt
-from more import LabelWordWrap, show_msg
+from more import LabelWordWrap, show_msg, get_icon
 import datetime
 from calculate.lib.datavars import DataVars
 
@@ -91,10 +91,9 @@ class HelpWgt(qt.QWidget):
         self.setFixedSize(self.sizeHint().width() + 50, \
                           self.sizeHint().height())
         self.setWindowTitle (_('Calculate Console '))
-        help_icon = qt.QIcon \
-                        ('/usr/share/pixmaps/calculate-console-online.svg')
-        if help_icon.isNull():
-            help_icon = qt.QIcon.fromTheme("help-about")
+        help_icon = get_icon(
+            '/usr/share/pixmaps/calculate-console-online.svg',
+            "help-about")
         self.setWindowIcon (help_icon)
 
         self.move(parent.window().geometry().x() + \
@@ -173,19 +172,8 @@ class BugWgt(qt.QWidget):
         # Set title and icon
         self.setWindowTitle (_('Calculate Console '))
         bug_icons = ['tools-report-bug','system-help','help-browser']
-        themeName = qt.QIcon.themeName()
-        bug_icon = qt.QIcon()
-        for image in bug_icons:
-            bug_icon.setThemeName(themeName)
-            bug_icon = bug_icon.fromTheme(image)
-            if not bug_icon.isNull():
-                break
-            bug_icon.setThemeName('Tango')
-            bug_icon = bug_icon.fromTheme(image)
-            if not bug_icon.isNull():
-                break
 
-        self.setWindowIcon(bug_icon)
+        self.setWindowIcon(get_icon(*bug_icons))
         self.setWindowTitle(_("Report a Bug"))
 
         self.move(parent.window().geometry().x() +
